import{S as p}from"./Sidebar.4230409a.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.76762e42.js";import{u as d,v as l,x as u}from"./icons.6f0b428b.js";import{d as b,eB as f,G as g,a as _,b as y,c as v,w as t,f as r}from"./outputWidgets.df68f70a.js";import{a as w}from"./asyncComputed.c4f3fa7a.js";import"./router.d34810ba.js";import"./index.5b8834fd.js";import{O as z}from"./organization.03354c62.js";import{B as h}from"./BaseLayout.6b00d238.js";import"./Tooltip.5e661364.js";import"./logo.084e5d7c.js";import"./index.c931e06a.js";import"./transButton.b32cb3fc.js";import"./Text.5293eafa.js";import"./Base.8da1f136.js";import"./Title.d7a9606c.js";import"./index.a1698b08.js";import"./record.493f7d84.js";import"./pubsub.26abae80.js";import"./gateway.104fd643.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[a]="f6587deb-0f75-4f27-abfb-653d70c80a2a",o._sentryDebugIdIdentifier="sentry-dbid-f6587deb-0f75-4f27-abfb-653d70c80a2a")}catch{}})();const J=b({__name:"Organization",setup(o){const n=f().params.organizationId,{result:e}=w(()=>z.get(n)),i=g(()=>e.value?[{label:"My organizations",path:"/organizations"},{label:e.value.name,path:`/organizations/${e.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:l,path:"members"},{name:"Billing",icon:u,path:"billing",unavailable:!0}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:t(()=>[r(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(p,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{J as default};
//# sourceMappingURL=Organization.f8ade64e.js.map
