import"./outputWidgets.df68f70a.js";import{M as r}from"./transButton.b32cb3fc.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="4c27701c-8e06-4663-81d4-a8456b9e7654",e._sentryDebugIdIdentifier="sentry-dbid-4c27701c-8e06-4663-81d4-a8456b9e7654")}catch{}})();function o(e){switch(typeof e){case"object":return Object.entries(e).map(([t,n])=>({title:t,key:t,children:o(n)}));default:return[{title:e,key:e}]}}function f(e){return new Promise(t=>{r.confirm({title:e,onOk:()=>t(!0),onCancel:()=>t(!1)})})}export{f as a,o as t};
//# sourceMappingURL=ant-design.4f24b7fc.js.map
