import"./outputWidgets.df68f70a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="d4c79797-28c9-4248-8f2e-ae98b20f3703",e._sentryDebugIdIdentifier="sentry-dbid-d4c79797-28c9-4248-8f2e-ae98b20f3703")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}};export{d as i};
//# sourceMappingURL=url.e14018a7.js.map
