import"./outputWidgets.df68f70a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[i]="f3b6d0b5-10bd-421b-9710-fe5486621af2",e._sentryDebugIdIdentifier="sentry-dbid-f3b6d0b5-10bd-421b-9710-fe5486621af2")}catch{}})();function f(e,i){const d=document,n=e.matched.slice().reverse().find(t=>t.meta&&t.meta.title),s=i.matched.slice().reverse().find(t=>t.meta&&t.meta.metaTags);n?d.title=n.meta.title:s&&(d.title=s.meta.title)}export{f as u};
//# sourceMappingURL=index.a1698b08.js.map
