import{cz as n}from"./outputWidgets.df68f70a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="79e986fe-bf44-4dcb-b8cf-9eb19a73e98b",e._sentryDebugIdIdentifier="sentry-dbid-79e986fe-bf44-4dcb-b8cf-9eb19a73e98b")}catch{}})();const t=(e,r)=>{n.error({message:e,description:r})};export{t as p};
//# sourceMappingURL=popupNotifcation.e5474436.js.map
