import{t,b as s,eu as o}from"./outputWidgets.df68f70a.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="b0a22eed-483f-48e7-9e95-a4d2ec75f273",e._sentryDebugIdIdentifier="sentry-dbid-b0a22eed-483f-48e7-9e95-a4d2ec75f273")}catch{}})();const r={},a={class:"organization-settings"};function d(e,n){return s(),o("div",a,"Organization settings")}const f=t(r,[["render",d]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.4529774e.js.map
