import{d as u,eB as b,G as f,b as y,c as g,u as _}from"./outputWidgets.df68f70a.js";import{a as w}from"./asyncComputed.c4f3fa7a.js";import"./router.d34810ba.js";import"./index.5b8834fd.js";import{M as n}from"./member.62fd6cbe.js";import{C as I}from"./CrudView.8169c4b4.js";import"./Base.8da1f136.js";import"./transButton.b32cb3fc.js";import"./Text.5293eafa.js";import"./Title.d7a9606c.js";import"./index.a1698b08.js";import"./record.493f7d84.js";import"./pubsub.26abae80.js";import"./gateway.104fd643.js";import"./icons.6f0b428b.js";import"./url.e14018a7.js";import"./index.4c2136c4.js";import"./index.f12da0b9.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="059ebf6d-93ab-4270-9c73-9eda149627c4",e._sentryDebugIdIdentifier="sentry-dbid-059ebf6d-93ab-4270-9c73-9eda149627c4")}catch{}})();const q=u({__name:"Members",setup(e){const r=b().params.organizationId,m=[{key:"email",label:"Email"}],s=async t=>{await n.create(r,t.email),p()},{loading:l,result:d,refetch:p}=w(()=>n.list(r)),c=f(()=>{var t,a;return{columns:[{name:"Email"},{name:"Role"}],rows:(a=(t=d.value)==null?void 0:t.map(i=>({key:i.email,cells:[{text:i.email},{text:i.role}]})))!=null?a:[]}});return(t,a)=>(y(),g(I,{"entity-name":"members",loading:_(l),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:c.value,"create-button-text":"Add members",fields:m,onCreate:s},null,8,["loading","table"]))}});export{q as default};
//# sourceMappingURL=Members.fe611893.js.map
