var l=Object.defineProperty;var d=(s,t,e)=>t in s?l(s,t,{enumerable:!0,configurable:!0,writable:!0,value:e}):s[t]=e;var r=(s,t,e)=>(d(s,typeof t!="symbol"?t+"":t,e),e);import{g as w,h as g,_ as p,S as h,q as b}from"./outputWidgets.df68f70a.js";import{P as v}from"./pubsub.26abae80.js";(function(){try{var s=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(s._sentryDebugIds=s._sentryDebugIds||{},s._sentryDebugIds[t]="43e56090-aa56-4186-839e-50ab2382ab5c",s._sentryDebugIdIdentifier="sentry-dbid-43e56090-aa56-4186-839e-50ab2382ab5c")}catch{}})();const m=[{path:"/:path(.*)*",name:"player",component:()=>p(()=>import("./Player.48699527.js"),["assets/Player.48699527.js","assets/FormRunner.007f8bce.js","assets/outputWidgets.df68f70a.js","assets/outputWidgets.c8d85cd0.css","assets/url.e14018a7.js","assets/icons.6f0b428b.js","assets/CircularLoading.4c177a66.js","assets/CircularLoading.f81b57b4.css","assets/PlayerNavbar.1abe1cfa.js","assets/PlayerNavbar.d1d85d81.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.75374b89.js","assets/ActionButton.998aa76d.css","assets/WidgetsFrame.603ed1d3.js","assets/WidgetsFrame.97ae601d.css","assets/FormRunner.76ed3612.css","assets/uuid.6bec6d4e.js","assets/asyncComputed.c4f3fa7a.js","assets/pubsub.26abae80.js","assets/Player.8da60c29.css"])}],_=w({history:g("/"),routes:m,scrollBehavior(s){if(s.hash)return{el:s.hash}}}),c=class{constructor(t,e){this.providerConfig=t,this.userManager=e}static async init(t,e){c.instance=new c(t,e)}get provider(){return this.providerConfig.provider}async authenticate(t){try{const e=await fetch(`${this.providerConfig.authority}/authenticate`,{method:"POST",headers:{"content-type":"application/json"},body:JSON.stringify({email:t})});if(!e.ok)throw new Error(await e.text());return null}catch(e){return e.message}}async verify(t,e){const f=await fetch(`${this.providerConfig.authority}/verify`,{method:"POST",headers:{"content-type":"application/json"},body:JSON.stringify({email:t,token:e})});if(!f.ok)return null;const y=await f.json();return this.userManager.saveJWT(y.jwt),this.userManager.getUser()}};let n=c;r(n,"instance",null);const a=class{constructor(t=new v){this.pubsub=t}saveJWT(t){h.set(a.key,t),this.notify()}notify(){const t=this.getUser();this.pubsub.publish("authenticated",t)}getJWT(){return h.get(a.key)}getUser(){const t=this.getJWT();if(t)try{const e=b(t);if(e.exp&&e.exp>Date.now()/1e3)return{jwt:t,claims:e}}catch{console.warn("Invalid JWT")}return null}removeUser(){this.pubsub.publish("authenticated",null),h.remove(a.key)}};let i=a;r(i,"key","abstra:auth:jwt");const k=new i;async function j(){const s=await fetch("/_auth/config");if(!s.ok)throw new Error(await s.text());const t=await s.json();await n.init(t,k)}async function S(){const s=await fetch("/_settings");if(!s.ok)throw new Error(await s.text());const t=await s.json();await o.init(t)}const u=class{constructor(t){this.config=t}static async init(t){u.instance=new u(t)}get showWatermark(){return this.config.show_watermark}get deployEnabled(){return{}.VITE_ABSTRA_RELEASE!=="staging"}};let o=u;r(o,"instance",null);export{n as A,o as S,_ as a,k as b,m as r,S as s,j as u};
//# sourceMappingURL=index.4e130cd7.js.map
