import{U as c}from"./outputWidgets.df68f70a.js";import{c as s,d as i}from"./index.a46bddee.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="e9300ee0-21a8-4845-a63c-dd0d38d6ca88",e._sentryDebugIdIdentifier="sentry-dbid-e9300ee0-21a8-4845-a63c-dd0d38d6ca88")}catch{}})();const{DatePicker:n,WeekPicker:r,MonthPicker:t,YearPicker:m,TimePicker:f,QuarterPicker:a,RangePicker:o}=s(i),g=c(n,{WeekPicker:r,MonthPicker:t,YearPicker:m,RangePicker:o,TimePicker:f,QuarterPicker:a,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(t.name,t),e.component(r.name,r),e.component(a.name,a),e)});export{g as D,t as M,a as Q,o as R,r as W};
//# sourceMappingURL=dayjs.1999775d.js.map
