import{ee as i,ab as b,U as s,f as p,O as d}from"./outputWidgets.df68f70a.js";import{B as y,a as u}from"./Base.8da1f136.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="0df1aab9-7c34-4cbe-a006-6e0cfb9bac09",e._sentryDebugIdIdentifier="sentry-dbid-0df1aab9-7c34-4cbe-a006-6e0cfb9bac09")}catch{}})();var g=globalThis&&globalThis.__rest||function(e,o){var n={};for(var t in e)Object.prototype.hasOwnProperty.call(e,t)&&o.indexOf(t)<0&&(n[t]=e[t]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var r=0,t=Object.getOwnPropertySymbols(e);r<t.length;r++)o.indexOf(t[r])<0&&Object.prototype.propertyIsEnumerable.call(e,t[r])&&(n[t[r]]=e[t[r]]);return n};const m=i(1,2,3,4,5),_=()=>s(s({},d(u(),["component","strong"])),{level:Number}),a=(e,o)=>{let{slots:n,attrs:t}=o;const{level:r=1}=e,c=g(e,["level"]);let l;m.includes(r)?l=`h${r}`:(b(),l="h1");const f=s(s(s({},c),{component:l}),t);return p(y,f,n)};a.displayName="ATypographyTitle";a.inheritAttrs=!1;a.props=_();const T=a;export{T as A};
//# sourceMappingURL=Title.d7a9606c.js.map
