import{d as k,eB as B,eA as w,G as I,a as h,b as o,c as d,w as a,eG as j,f as i,u as e,eu as l,eC as z,aq as g,eD as x,a_ as C,ew as D,bu as A,cF as S}from"./outputWidgets.df68f70a.js";import{B as $}from"./BaseLayout.6b00d238.js";import{a as M}from"./asyncComputed.c4f3fa7a.js";import{_ as N}from"./component.vue_vue_type_script_setup_true_lang.42a9aa86.js";import"./router.d34810ba.js";import{a as P}from"./build.e753c4c9.js";import"./index.5b8834fd.js";import{P as R}from"./project.7e3804c0.js";import{O as V}from"./organization.03354c62.js";import{B as E,a as F,c as G}from"./index.c931e06a.js";import{c as L}from"./Text.5293eafa.js";import"./icons.6f0b428b.js";import"./index.4b760d43.js";import"./Base.8da1f136.js";import"./transButton.b32cb3fc.js";import"./Title.d7a9606c.js";import"./index.a1698b08.js";import"./gateway.104fd643.js";import"./record.493f7d84.js";import"./pubsub.26abae80.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[s]="f7b0d947-c98e-42ae-9931-1993cea969c8",n._sentryDebugIdIdentifier="sentry-dbid-f7b0d947-c98e-42ae-9931-1993cea969c8")}catch{}})();const O={key:0},T={key:2},ce=k({__name:"Build",setup(n){const s=B(),p=w(),m=s.params.buildId,{result:t,loading:f}=M(async()=>{const r=await P.get(m),u=await R.get(r.projectId),c=await V.get(u.organizationId);return j({bs:r,project:u,organization:c})}),b=I(()=>!f.value&&t.value?[{label:"My organizations",path:"/organizations"},{label:t.value.organization.name,path:`/organizations/${t.value.organization.id}`},{label:`Build ${m.split("-")[0]}`,path:`/projects/${t.value.project.id}/builds`}]:void 0);function y(){var r;(r=t.value)!=null&&r.project.id&&p.push({name:"builds",params:{projectId:t.value.project.id}})}return(r,u)=>{const c=h("router-link");return o(),d($,null,{navbar:a(()=>[i(e(G),{title:"Inspect Build",style:{padding:"5px 10px"},onBack:y},{breadcrumb:a(()=>[b.value?(o(),d(e(E),{key:0},{default:a(()=>[(o(!0),l(C,null,z(b.value,(_,v)=>(o(),d(e(F),{key:v},{default:a(()=>[i(c,{to:_.path},{default:a(()=>[g(x(_.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):D("",!0)]),_:1})]),content:a(()=>[e(f)?(o(),l("div",O,[i(e(A))])):e(t)?(o(),d(N,{key:1,"build-spec":e(t).bs},null,8,["build-spec"])):(o(),l("div",T,[i(e(S),{direction:"vertical"},{default:a(()=>[i(e(L),null,{default:a(()=>[g("Could not find build")]),_:1})]),_:1})]))]),_:1})}}});export{ce as default};
//# sourceMappingURL=Build.def836cb.js.map
